@@ -4,7 +4,7 @@ import (
 	"net/url"
 
 	"github.com/armosec/k8s-interface/workloadinterface"
-	"github.com/armosec/kubescape/core/cautils/getter"
+	"github.com/armosec/kubescape/v2/core/cautils/getter"
 	"github.com/armosec/opa-utils/reporthandling"
 	"github.com/google/uuid"
 )
